@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.0.0-0
+# Application Name - Health Check V1.1.0-0
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -68,10 +68,6 @@ except:
 	print "Unexpected error: Importing location"
 	raise
 
-# GPS ones
-# Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
-# can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
-
 print "** Importing Cellinfo **"
 try:
 	import gn_cellinfo
@@ -86,9 +82,6 @@ except:
 	print "Unexpected error: Importing hildon"
 	raise
 
-#for phone orientation call
-#import dbus
-#import dbus.glib
 print "** Importing Threading **"
 try:
 	from threading import Thread
@@ -143,28 +136,24 @@ name_lookup = {}
 rootfs_id = ''
 
 
-class imagea(QtGui.QMainWindow):
+class camerasClass(QtGui.QMainWindow):
 
 	def __init__(self, *args):
 		
 		apply(QtGui.QMainWindow.__init__, (self,) + args)
-		print "** Starting Hellowindow Class **"
-		#self.Qt::WA_Maemo5StackedWindow 
 		print "** Set basic color on rectangle **"
 		self.color = QtGui.QColor(0, 0, 0) 
 		print "** Setting window details and loading form**"
 		self.setGeometry(0, 0, 800, 480)
 		self.setWindowTitle('Front Camera Image')
-		
-
-		self.lbl_CameraShow = QtGui.QLabel(self)
-		self.lbl_CameraShow.setGeometry(QtCore.QRect(160, 10, 455, 341))
-		self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
-		self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
-		self.lbl_CameraShow.setLineWidth(2)
-		self.lbl_CameraShow.setMidLineWidth(1)
-		self.lbl_CameraShow.setScaledContents(True)
-		self.lbl_CameraShow.setObjectName("lbl_CameraShow")
+		self.lblCameraImage = QtGui.QLabel(self)
+		self.lblCameraImage.setGeometry(QtCore.QRect(160, 10, 455, 341))
+		self.lblCameraImage.setFrameShape(QtGui.QFrame.Panel)
+		self.lblCameraImage.setFrameShadow(QtGui.QFrame.Raised)
+		self.lblCameraImage.setLineWidth(2)
+		self.lblCameraImage.setMidLineWidth(1)
+		self.lblCameraImage.setScaledContents(True)
+		self.lblCameraImage.setObjectName("lblCameraImage")
 
 		
 		# Setup and draw the button
@@ -172,7 +161,7 @@ class imagea(QtGui.QMainWindow):
 		self.pushButton_cam.setGeometry(QtCore.QRect(10, 380, 331, 71))
 		self.pushButton_cam.setObjectName("pushButton_cam")
 		self.pushButton_cam.setText("Front camera")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+		# Tell the button what to do when it is clicked.
 		QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
 
 		# Setup and draw the button
@@ -180,7 +169,7 @@ class imagea(QtGui.QMainWindow):
 		self.pushButton_cam2.setGeometry(QtCore.QRect(350, 380, 331, 71))
 		self.pushButton_cam2.setObjectName("pushButton_cam2")
 		self.pushButton_cam2.setText("Back camera")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+		# Tell the button what to do when it is clicked.
 		QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
 
 		self.exitb = QtGui.QPushButton('X', self)
@@ -203,6 +192,7 @@ class imagea(QtGui.QMainWindow):
 		self.updateImage2()
 		self.pushButton_cam2.setText("Back Camera")
 		self.pushButton_cam2.setEnabled(True)
+
 	# Funtion - update the front camera image
 	def updateImage(self):
 		print "** Starting front camera function **"
@@ -210,17 +200,13 @@ class imagea(QtGui.QMainWindow):
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		interface.Notify('HealthCheck', 0, 'general_refresh', 'Front Camera', 'Point your screen camera at a light.', [], {}, 3000)
-		# Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
 		b = None
-		# X-term - grab 10 buffered front camera images, and throw them into an image file.
-		# Everyone recommends 1.... but 10 gave more light! - so i used it :D
 		b = os.popen('gst-launch v4l2camsrc device=/dev/video1 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
 		b.close ()
-		# Declare and set the image file name
 		image_file = "/home/user/MyDocs/fcamtest.jpg"
 		image = QtGui.QPixmap(image_file)
 		# Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-		self.lbl_CameraShow.setPixmap(image)
+		self.lblCameraImage.setPixmap(image)
 		print " ** Finished front camera function **"
 
 	def updateImage2(self):
@@ -247,7 +233,7 @@ class imagea(QtGui.QMainWindow):
 				image_file = "/home/user/MyDocs/fcamtest.jpg"
 				image = QtGui.QPixmap(image_file)
 				# Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-				self.lbl_CameraShow.setPixmap(image)
+				self.lblCameraImage.setPixmap(image)
 				print " ** Finished Back camera function **"
 			elif self.CloseDialog == QtGui.QMessageBox.No:
 				print "** User pressed 'No' button - returning **"
@@ -262,7 +248,7 @@ class imagea(QtGui.QMainWindow):
 			image_file = "/home/user/MyDocs/fcamtest.jpg"
 			image = QtGui.QPixmap(image_file)
 			# Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-			self.lbl_CameraShow.setPixmap(image)
+			self.lblCameraImage.setPixmap(image)
 			print " ** Finished Back camera function **"
 
 
@@ -407,8 +393,7 @@ class Ui_MainWindow(object):
 		#MainWindow.menuBar().addSeparator()
 		#actd = fremantle.addAction("Apps")
 		#QtCore.QObject.connect(actd, QtCore.SIGNAL("triggered()"), self.listpackages)
-
-
+                
 
 		# Creating the tab that i need for my application, and set it's size
 		self.tabWidget = QtGui.QTabWidget(self.centralwidget)
@@ -432,22 +417,8 @@ class Ui_MainWindow(object):
 		self.listWidget.setAlternatingRowColors(True)
 		self.listWidget.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
 		self.listWidget.setResizeMode(QtGui.QListView.Adjust)
+		QtCore.QObject.connect(self.listWidget, QtCore.SIGNAL("itemClicked(QListWidgetItem *)"), self.lclicked) 
 		
-		# Setup and draw the button
-		#self.pushButton_hw = QtGui.QPushButton(self.tab)
-		#self.pushButton_hw.setGeometry(QtCore.QRect(0, 310, 500, 51))
-		#self.pushButton_hw.setObjectName("pushButton_hw")
-		#self.pushButton_hw.setText("Update Tab")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-		#QtCore.QObject.connect(self.pushButton_hw, QtCore.SIGNAL('clicked()'), self.updateTab1)
-
-		# Setup and draw the button
-		#self.pushButton_a1 = QtGui.QPushButton(self.tab)
-		#self.pushButton_a1.setGeometry(QtCore.QRect(500, 310, 300, 51))
-		#self.pushButton_a1.setObjectName("pushButton_a1")
-		#self.pushButton_a1.setText("Update All")
-		## Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-		#QtCore.QObject.connect(self.pushButton_a1, QtCore.SIGNAL('clicked()'), self.updateAll)
 				
 		# Draw the Tab Contents
 		self.tabWidget.addTab(self.tab, "")
@@ -464,41 +435,8 @@ class Ui_MainWindow(object):
 		self.listWidget2.setAlternatingRowColors(True)
 		self.listWidget2.setResizeMode(QtGui.QListView.Adjust)
 
-		# Setup and draw the button
-		#self.pushButton_com = QtGui.QPushButton(self.tab_2)
-		#self.pushButton_com.setGeometry(QtCore.QRect(0, 310, 500, 51))
-		#self.pushButton_com.setObjectName("pushButton_com")
-		#self.pushButton_com.setText("Update Tab")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-		#QtCore.QObject.connect(self.pushButton_com, QtCore.SIGNAL('clicked()'), self.updateTab2)
-
-		# Setup and draw the button
-		#self.pushButton_a2 = QtGui.QPushButton(self.tab_2)
-		#self.pushButton_a2.setGeometry(QtCore.QRect(500, 310, 300, 51))
-		#self.pushButton_a2.setObjectName("pushButton_a2_2")
-		#self.pushButton_a2.setText("Update All")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-		#QtCore.QObject.connect(self.pushButton_a2, QtCore.SIGNAL('clicked()'), self.updateAll)
-
 		# Show the tab and draw contents
 		self.tabWidget.addTab(self.tab_2, "")
-
-		# Start on tab 3!
-		#self.tab_3 = QtGui.QWidget()
-		#self.tab_3.setObjectName("tab_3")
-
-		#font = QtGui.QFont()
-		#font.setPointSize(12)
-		# Set up the Front Camera label
-
-		# This label is used to show the Front Camera widget
-		#self.listApps = QtGui.QListWidget(self.tab_3)
-		#self.listApps.setGeometry(QtCore.QRect(1, 0, 799, 361))
-		#self.listApps.setObjectName("listApps")
-		#self.listApps.setFont(font)
-		#self.listApps.setAlternatingRowColors(True)
-		#self.listApps.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
-		#self.listApps.setResizeMode(QtGui.QListView.Adjust)
 		
 
 		# Show the tab and draw contents
@@ -602,7 +540,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V1.0.0-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
+		self.textBrowser.setText (" Health Check V1.1.0-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -622,6 +560,79 @@ class Ui_MainWindow(object):
 		self.tabWidget.setCurrentIndex(0)
 		QtCore.QMetaObject.connectSlotsByName(MainWindow)
 
+	def lclicked(self):
+                #print self.listWidget.currentRow()
+                #print self.listWidget.selectedItems()
+                selected_items = ", ".join([str(item.text()) for item in self.listWidget.selectedItems()])
+                sela = selected_items.split('\t')
+                print "selected:", sela[0].strip()
+
+                if sela[0].strip() == "Accelerometer":
+                        print " ** Getting accel co-ords**"
+                        f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r')
+                        coords = [int(w) for w in f.readline().split()]
+                        f.close()
+                        print " ** Getting orientation**"
+                        b = None
+                        b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
+                        coords = str(coords)
+                        jaccel = str(coords) + str(b)
+                        self.listWidget.currentItem().setText("Accelerometer \t\t" + jaccel)
+                elif sela[0].strip() == "Battery Charge":
+                        print " ** Getting battery charge**"
+                        gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Battery Charge \t\t" + gl.strip())
+                elif sela[0].strip() == "Battery Current":
+                        print " ** Getting battery mAh info**"
+                        gl = os.popen('hal-device bme | awk \'/g.c/ {print $3" mAh"}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Battery Current \t\t" + gl.strip())
+                elif sela[0].strip() == "Camera Shutter State":
+                        print " ** Getting Cam Shutter State**"
+                        gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Camera Shutter State \t" + gl.strip())
+                elif sela[0].strip() == "FM Trans Strength":
+                        print " ** Getting FM Transmitter power level **"
+                        ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
+                        ge = ge.strip()
+                        self.listWidget.currentItem().setText("FM Trans Strength \t\t" + ge.strip())
+                elif sela[0].strip() == "Headphone State":
+                        print " ** Getting headphone state**"
+                        gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Headphone State \t\t" + gl.strip())
+                elif sela[0].strip() == "Keyboard Slider State":
+                        print " ** Getting Keyboard Slider State**"
+                        gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Keyboard Slider State \t" + gl.strip())
+                elif sela[0].strip() == "Proximity Sensor State":
+                        print " ** Getting proximity sensor state**"
+                        gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Proximity Sensor State \t" + gl.strip())
+                elif sela[0].strip() == "System Uptime":
+                        print " ** Getting system uptime**"
+                        ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
+                        self.listWidget.currentItem().setText("System Uptime \t\t" + ge.strip())
+                elif sela[0].strip() == "CPU Current Freq":
+                        print " ** Getting CPU Frequency **"
+                        QtGui.QApplication.processEvents()
+                        time.sleep(0.2)
+                        gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`/1000)) MHz').read()
+                        QtGui.QApplication.processEvents()
+                        time.sleep(0.2)
+                        gl = gl.strip()
+                        self.listWidget.addItem("CPU Current Freq \t\t" + gl.strip())
+                else:
+                        print "else", sela[0].strip()
+                
+
+        
+
+
 	def show_new_window(self):           
 		win.show()
 		win.showFullScreen()
@@ -638,23 +649,8 @@ class Ui_MainWindow(object):
 
 		self.listApps.clear()
 		self.checkpkgs()
-		self.listApps.sortItems()		
+		self.listApps.sortItems()
 
-	
-
-	# Get the total rootfs size for all non-l10n packages
-	def checkpkgs(self):
-		print " ** Getting applications list **"
-		#gl = os.popen('grep Package: /var/lib/dpkg/available').read()
-		fh = open("/var/lib/dpkg/available","r")
-		igot = fh.readlines()
-		print " ** Adding applications to listbox **"
-		for line in igot:
-			if line.find("Package:") > -1:
-				about = line.split()
-				#print about[0],
-				self.listApps.addItem(about[1])
-				self.listApps.sortItems()
 	def cpufreq(self):
 		print " ** Opening CPU Frequency File**"
 		fh = open("/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies","r")
@@ -668,13 +664,10 @@ class Ui_MainWindow(object):
                                 aa = str(aa) + str((int(words)/1000)) + "MHz, "
 
                 print aa
-                self.listWidget.addItem("CPU Avail Freq \t\t" + aa)
-                                
-                        
-                               
-
-
-				
+                aa = aa.strip()[:-1]
+                print "**",aa,"**"
+                self.listWidget.addItem("CPU Frequencies \t\t" + aa)
+                                	
 		
 		
 # Funtion - update GPS - Using lib-location
@@ -802,19 +795,17 @@ class Ui_MainWindow(object):
 				
 		print " ** Getting board info**"
 		gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
-		gb = gb.strip()[11:]
-		
+		gb = gb.strip()[11:]		
 		self.listWidget.addItem("N900 Board \t\t\t" + gb.strip())
+		
 		print " ** Getting board info revision **"
 		gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
 		gj = gj.strip()[11:]
-		
 		self.listWidget.addItem("N900 Board Revision \t" + gj.strip())
 
 		print " ** Getting system locale**"
 		gc = os.popen('locale | grep LANG').read()
 		gc = gc.strip()[5:]
-		
 		self.listWidget.addItem("System Locale \t\t" + gc.strip())
 
 		print " ** Getting boot count**"
@@ -830,7 +821,7 @@ class Ui_MainWindow(object):
 		print " ** Getting Boot Reason**"
 		gl = os.popen('cat /proc/bootreason').read()
 		gl = gl.strip()	
-		self.listWidget.addItem("Boot Reason (last) \t\t" + gl.strip())
+		self.listWidget.addItem("Boot Reason \t\t\t" + gl.strip())
 
 		print " ** Getting Cam Shutter State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
@@ -855,12 +846,12 @@ class Ui_MainWindow(object):
 		print " ** Getting battery mAh info**"
 		gl = os.popen('hal-device bme | awk \'/g.c/ {print $3" mAh"}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Battery current mAh \t\t" + gl.strip())
+		self.listWidget.addItem("Battery Current \t\t" + gl.strip())
 		
 		print " ** Getting battery mAh info2**"
 		gl = os.popen('hal-device bme | awk \'/g.la/ {print $3" mAh"}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Battery last charge mAh \t" + gl.strip())
+		self.listWidget.addItem("Battery Last Charge \t\t" + gl.strip())
 
  
 		
@@ -930,7 +921,7 @@ class Ui_MainWindow(object):
 		print " ** Getting battery charge**"
 		gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Battery charge \t\t" + gl.strip())
+		self.listWidget.addItem("Battery Charge \t\t" + gl.strip())
 
 # Funtion - update Accelerator information
 	def updateAccel(self):
@@ -989,7 +980,6 @@ class Ui_MainWindow(object):
 		print " ** finished vibrations**"
 		
 	def updateLED(self):
-		#print " ** importing dbus.glib**"
 		print " ** Starting LED Patterns**"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
@@ -1017,11 +1007,7 @@ class Ui_MainWindow(object):
 		interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Completed LED Test', [], {}, 3000)
 
 
-# Funtion - update rootfs, currently shows free MB and used %.
 	def updaterootfs(self):
-		print " ** Getting rootfs space commands**"
-		# Call the x-terminal command to read the rootfs free space
-
 		print " ** Getting rootfs % used **"
 		gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
 		gl = gl.strip()
@@ -1030,7 +1016,7 @@ class Ui_MainWindow(object):
 		print " ** Getting rootfs free MB **"
 		gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Rootfs MB Free \t\t" + gl.strip())
+		self.listWidget.addItem("Rootfs Free \t\t\t" + gl.strip())
 
 		print " ** Getting myDocs % Used **"
 		gl = os.popen('df /home/user/MyDocs | awk \'/My/ {print $5}\'').read()
@@ -1040,7 +1026,7 @@ class Ui_MainWindow(object):
 		print " ** Getting myDocs MB Free **"
 		gl = os.popen('df -h /home/user/MyDocs | awk \'/My/ {print $4}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("MyDocs MB Free \t\t" + gl.strip())
+		self.listWidget.addItem("MyDocs Free \t\t\t" + gl.strip())
 
 		print " ** Getting App Space **"
 		gl = os.popen('df /home | awk \'/ho/ {print $5}\'').read()
@@ -1050,7 +1036,7 @@ class Ui_MainWindow(object):
 		print " ** Getting App MB Free **"
 		gl = os.popen('df -h /home | awk \'/ho/ {print $4}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("App/Home MB Free \t\t" + gl.strip())
+		self.listWidget.addItem("App/Home Free \t\t" + gl.strip())
 
 		print " ** Getting MMC Space **"
 		gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
@@ -1066,21 +1052,6 @@ class Ui_MainWindow(object):
 		gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`/1000)) MHz').read()
 		gl = gl.strip()
 		self.listWidget.addItem("CPU Current Freq \t\t" + gl.strip())
-		
-		#print " ** Getting CPU Temperature **"
-		#gl = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
-		#gl = gl.strip()
-		#self.listWidget.addItem("CPU Temp (celcius) \t\t" + gl.strip())
-
-		#print " ** Getting RAM Used **"
-		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$3/1024)}\'').read()
-		#gl = gl.strip()
-		#self.listWidget.addItem("Memory - RAM Used \t" + gl.strip())
-		
-		#print " ** Getting RAM Free **"
-		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$4/1024)}\'').read()
-		#gl = gl.strip()
-		#self.listWidget.addItem("Memory - RAM Free \t" + gl.strip())
 
 		print " ** Getting Backlight Info **"
 		gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
@@ -1104,14 +1075,6 @@ class Ui_MainWindow(object):
 
 		self.cpufreq()
 
-		
-
-
-		
-
-		
-# Funtion - update tab.... Originally to update tab1, but using it to collate the functions
-# It has the commented out message boxes, will work on this later
 	def updateAll(self):
                 
 		print " ** Running Update ALL**"
@@ -1121,7 +1084,7 @@ class Ui_MainWindow(object):
 		progress.setAutoClose(True)
 		progress.setMinimum(0)
 		progress.setMaximum(100)
-		progress.resize(800,200)
+		progress.resize(800,100)
 		progress.setWindowTitle("Loading Healthcheck")
 		progress.show()
 		QtGui.QApplication.processEvents()
@@ -1277,17 +1240,11 @@ class Ui_MainWindow(object):
 		print 'done'
                 progress.hide()
 
-		#bus = dbus.SessionBus()
-		#proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-		#interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-		#interface.Notify('HealthCheck', 0, 'general_refresh', 'Comms Tab', 'Finished Loading', [], {}, 2000)
-		#print " ** Finished Tab 2 update **"
-
   
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.0.0-0", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.0-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
@@ -1348,10 +1305,6 @@ class Ui_MainWindow(object):
 		#self.lbl_pServices_Info.setText(services)
 		print " ** Finishing Cellular **"
 
-
-				
-
-
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
 # Moved out of the class by me
 def on_error(control, error, user_data):
@@ -1414,37 +1367,27 @@ def start_location(data):
 	data.start()
 	return False
 
-
-
-
 # Start the main program/function
 if __name__ == "__main__":
-	import sys
 	print " ** Starting Main **"
 	print " ** app = QtGui App** - Running app = QtGui.QApplication(sys.argv) **"
 	app = QtGui.QApplication(sys.argv)
-	#QtGui.QApplication.setStyle(QtGui.QStyleFactory.create('windowsxp'))
-	#app = QtGui.QApplication(sys.argv)
 	print " ** Setting Main Window**"
 	MainWindow = QtGui.QMainWindow()
-	#appt=QtGui.QApplication(sys.argv)
 	print "** Setting tool window #1**"
 	win = HelloWindow(MainWindow)
 	print "** Setting tool window #2**"
 	aui = aMainWindow(MainWindow)
 	print "** Setting Video window**"
-	imagewin = imagea(MainWindow)
+	imagewin = camerasClass(MainWindow)
 	print " ** Declare the UI**"
 	ui = Ui_MainWindow()
 	print " ** Draw everything and start the main function**"
 	ui.setupUi(MainWindow)
 	print " ** Show everything**"
-	
 	MainWindow.show()
-	#MainWindow.setAttribute(QtCore.WA_Maemo5ShowProgressIndicator, False)
 	print " ** Waiting for quit signal - healthcheck loaded **"
 	ui.updateAll()
-	
 	sys.exit(app.exec_())
 	print " ** sys.exit called**"
 
